==> okio-jvm-3.0.0-javadoc.jar: okio/okio/-buffer/-unsafe-cursor/expand-buffer.md <==
//[okio](../../../../index.md)/[okio](../../index.md)/[Buffer](../index.md)/[UnsafeCursor](index.md)/[expandBuffer](expand-buffer.md)

# expandBuffer

[common]\
fun [expandBuffer](expand-buffer.md)(minByteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)

Grow the buffer by adding a **contiguous range** of capacity in a single segment. This adds at least [minByteCount](expand-buffer.md) bytes but may add up to a full segment of additional capacity.

As a side-effect this cursor will [seek](seek.md). It will move [offset](offset.md) to the first byte of newly-added capacity. This is the size of the buffer prior to the expandBuffer() call.

If [minByteCount](expand-buffer.md) bytes are available in the buffer's current tail segment that will be used; otherwise another segment will be allocated and appended. In either case this returns the number of bytes of capacity added to this buffer.

Warning: it is the caller’s responsibility to either write new data to every byte of the newly-allocated capacity, or to [shrink](resize-buffer.md) the buffer to the data written. Failure to do so may cause serious security problems as the data in the returned buffers is not zero filled. Buffers may contain dirty pooled segments that hold very sensitive data from other parts of the current process.

#### Return

the number of bytes expanded by. Not less than minByteCount.

## Parameters

common

| | |
|---|---|
| minByteCount | the size of the contiguous capacity. Must be positive and not greater     than the capacity size of a single segment (8 KiB). |

jvm

| | |
|---|---|
| minByteCount | the size of the contiguous capacity. Must be positive and not greater     than the capacity size of a single segment (8 KiB). |

[jvm]\
fun [expandBuffer](expand-buffer.md)(minByteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)

## Parameters

common

| | |
|---|---|
| minByteCount | the size of the contiguous capacity. Must be positive and not greater     than the capacity size of a single segment (8 KiB). |

jvm

| | |
|---|---|
| minByteCount | the size of the contiguous capacity. Must be positive and not greater     than the capacity size of a single segment (8 KiB). |

==> okio-jvm-3.3.0-javadoc.jar: okio/okio/-buffer/-unsafe-cursor/expand-buffer.md <==
//[okio](../../../../index.md)/[okio](../../index.md)/[Buffer](../index.md)/[UnsafeCursor](index.md)/[expandBuffer](expand-buffer.md)

# expandBuffer

[common]\
expect fun [expandBuffer](expand-buffer.md)(minByteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)

Grow the buffer by adding a **contiguous range** of capacity in a single segment. This adds at least [minByteCount](expand-buffer.md) bytes but may add up to a full segment of additional capacity.

As a side-effect this cursor will [seek](seek.md). It will move [offset](offset.md) to the first byte of newly-added capacity. This is the size of the buffer prior to the `expandBuffer()` call.

If [minByteCount](expand-buffer.md) bytes are available in the buffer's current tail segment that will be used; otherwise another segment will be allocated and appended. In either case this returns the number of bytes of capacity added to this buffer.

Warning: it is the caller’s responsibility to either write new data to every byte of the newly-allocated capacity, or to [shrink](resize-buffer.md) the buffer to the data written. Failure to do so may cause serious security problems as the data in the returned buffers is not zero filled. Buffers may contain dirty pooled segments that hold very sensitive data from other parts of the current process.

#### Return

the number of bytes expanded by. Not less than `minByteCount`.

## Parameters

common

| | |
|---|---|
| minByteCount | the size of the contiguous capacity. Must be positive and not greater     than the capacity size of a single segment (8 KiB). |

[jvm, nonJvm]\
[jvm, nonJvm]\
actual fun [expandBuffer](expand-buffer.md)(minByteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)
